@@ -23,6 +23,8 @@ RESULT_PATH = PROJECT_ROOT / "result"
 SCORE_PATH = PROJECT_ROOT / "score"
 DOTENV_PATH = PROJECT_ROOT / ".env"
 TEST_IDS_TO_GENERATE_PATH = PROJECT_ROOT / "test_case_ids_to_generate.json"
+# Directory that stores all lock files (kept out of the results tree)
+LOCK_DIR = PROJECT_ROOT / ".file_locks"
 
 PROMPT_PATH = PACKAGE_ROOT / "data"
 MULTI_TURN_FUNC_DOC_PATH = PROMPT_PATH / "multi_turn_func_doc"
@@ -38,3 +40,4 @@ RESET = "\033[0m"
 
 RESULT_PATH.mkdir(parents=True, exist_ok=True)
 SCORE_PATH.mkdir(parents=True, exist_ok=True)
+LOCK_DIR.mkdir(parents=True, exist_ok=True)
