@@ -1096,8 +1096,8 @@ api_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=True,
     ),
-    "kimi-k2-0711-preview-FC": ModelConfig(
-        model_name="moonshotai/Kimi-K2-Instruct",
+    "kimi-k2-0905-preview-FC": ModelConfig(
+        model_name="kimi-k2-0905-preview",
         display_name="Moonshotai-Kimi-K2-Instruct (FC)",
         url="https://huggingface.co/moonshotai/Kimi-K2-Instruct",
         org="MoonshotAI",
@@ -1108,8 +1108,8 @@ api_inference_model_map = {
         is_fc_model=True,
         underscore_to_dot=True,
     ),
-    "kimi-k2-0711-preview": ModelConfig(
-        model_name="moonshotai/Kimi-K2-Instruct",
+    "kimi-k2-0905-preview": ModelConfig(
+        model_name="kimi-k2-0905-preview",
         display_name="Moonshotai-Kimi-K2-Instruct (Prompt)",
         url="https://huggingface.co/moonshotai/Kimi-K2-Instruct",
         org="MoonshotAI",
