@@ -15,9 +15,17 @@ class PhiFCHandler(OSSHandler):
     - microsoft/Phi-4-mini-instruct
     """
 
-    def __init__(self, model_name, temperature) -> None:
-        super().__init__(model_name, temperature)
-        self.model_name_huggingface = model_name.replace("-FC", "")
+    def __init__(
+        self,
+        model_name,
+        temperature,
+        registry_name,
+        is_fc_model,
+        dtype="bfloat16",
+        **kwargs,
+    ) -> None:
+        super().__init__(model_name, temperature, registry_name, is_fc_model, **kwargs)
+        self.model_name_huggingface = model_name
         self.is_fc_model = True
 
     @override
