@@ -8,10 +8,17 @@ from overrides import override
 
 
 class QwenFCHandler(OSSHandler):
-    def __init__(self, model_name, temperature) -> None:
-        super().__init__(model_name, temperature)
-        self.is_fc_model = True
-        self.model_name_huggingface = model_name.replace("-FC", "")
+    def __init__(
+        self,
+        model_name,
+        temperature,
+        registry_name,
+        is_fc_model,
+        dtype="bfloat16",
+        **kwargs,
+    ) -> None:
+        super().__init__(model_name, temperature, registry_name, is_fc_model, **kwargs)
+        self.model_name_huggingface = model_name
 
     @override
     def decode_ast(self, result, language, has_tool_call_tag):
