@@ -1,8 +1,11 @@
 import json
 import os
+import hashlib
 import re
 from copy import deepcopy
 from pathlib import Path
+from threading import Lock
+from filelock import FileLock
 from typing import Union
 
 from bfcl_eval.constants.category_mapping import *
@@ -15,6 +18,28 @@ from bfcl_eval.constants.executable_backend_config import (
     MULTI_TURN_FUNC_DOC_FILE_MAPPING,
 )
 
+_FILE_LOCK_REGISTRY: dict[str, FileLock] = {}
+_FILE_LOCK_REGISTRY_LOCK = Lock()
+
+
+def _get_file_lock(filepath: str) -> FileLock:
+    """
+    Get a file lock for a given file path.
+    This function returns a cross-process file lock (using the `filelock` library) to prevent multiple
+    processes or threads from writing to the same target file at the same time. All lock files are
+    colocated in the hidden directory `LOCK_DIR` so they don’t clutter the actual data folders.
+    """
+    digest = hashlib.sha1(os.path.abspath(filepath).encode()).hexdigest()
+    lock_path = str(LOCK_DIR / f"{digest}.lock")
+    with _FILE_LOCK_REGISTRY_LOCK:
+        lock = _FILE_LOCK_REGISTRY.get(lock_path)
+        if lock is None:
+            # Each file has its own lock file on disk; FileLock ensures cross-process exclusivity.
+            lock = FileLock(lock_path)
+            _FILE_LOCK_REGISTRY[lock_path] = lock
+        return lock
+
+
 #### Helper functions to extract/parse/complete test category from different formats ####
 
 
@@ -327,50 +352,21 @@ def get_directory_structure_by_category(test_category: str) -> str:
 #### Helper functions to load/write the dataset files ####
 
 
-def load_file(file_path, sort_by_id=False, allow_concatenated_json=False):
+def load_file(file_path, sort_by_id: bool = False, use_lock: bool = True) -> list[dict]:
     result = []
-    with open(file_path) as f:
-        file = f.readlines()
-        for line in file:
-            try:
+
+    def _load_entries(input_path: str) -> None:
+        with open(input_path) as f:
+            file = f.readlines()
+            for line in file:
                 content = json.loads(line)
                 result.append(content)
-            except Exception as e:
-                if not allow_concatenated_json:
-                    raise e
 
-                # Although this really shouldn't happen, sometimes a result file might have more than one JSON objects concatenated on a single line instead of one per line (e.g. '{"id": 1, xxx}{"id": 2, xxx}').
-                # We can parse them incrementally by using `json.JSONDecoder.raw_decode`, which returns both the parsed object and the index where it stopped parsing.
-                line_jsons = []
-                decoder = json.JSONDecoder()
-                idx = 0
-                while idx < len(line):
-                    # Skip whitespace between objects (if any)
-                    while idx < len(line) and line[idx].isspace():
-                        idx += 1
-
-                    if idx >= len(line):
-                        break
-
-                    try:
-                        json_obj, idx = decoder.raw_decode(line, idx)
-                        line_jsons.append(json_obj)
-                    except json.JSONDecodeError:
-                        # If decoding fails at any point, the entire line is invalid.
-                        raise e
-
-                # After parsing, we must ensure the entire line has been consumed.
-                # If `idx` is not at the end of the line, it means there's trailing
-                # garbage, which is an error.
-                if idx < len(line):
-                    raise e
-
-                if not line_jsons:
-                    # If the line was non-empty but contained no JSON objects (e.g., only whitespace),
-                    # it's an error.
-                    raise e
-
-                result.extend(line_jsons)
+    if use_lock:
+        with _get_file_lock(file_path):
+            _load_entries(file_path)
+    else:
+        _load_entries(file_path)
 
     if sort_by_id:
         result.sort(key=sort_key)
@@ -382,22 +378,25 @@ def sort_file_content_by_id(file_path: Path) -> None:
     Sort the content of a file by the id of the entries. The file is only rewritten
     when the ordering actually changes to avoid unnecessary disk writes.
     """
-    # Load the current content preserving original order (and potential duplicates)
-    original_entries = load_file(file_path, allow_concatenated_json=True)
+    # Acquire the lock for the entire critical section
+    with _get_file_lock(file_path):
+        # Load the current content preserving original order (and potential duplicates)
+        original_entries = load_file(file_path, use_lock=False)
 
-    # Desired final ordering (sorted, unique)
-    sorted_entries = sorted(original_entries, key=sort_key)
+        # Desired final ordering (sorted, unique)
+        sorted_entries = sorted(original_entries, key=sort_key)
 
-    assert len(original_entries) == len(
-        sorted_entries
-    ), "There should be no duplicates in the file"
+        assert len(original_entries) == len(
+            sorted_entries
+        ), "There should be no duplicates in the file"
 
-    # Check if the write is necessary by comparing id sequences
-    original_ids = [entry["id"] for entry in original_entries]
-    sorted_ids = [entry["id"] for entry in sorted_entries]
+        # Check if the write is necessary by comparing id sequences
+        original_ids = [entry["id"] for entry in original_entries]
+        sorted_ids = [entry["id"] for entry in sorted_entries]
 
-    if original_ids != sorted_ids:
-        write_list_of_dicts_to_file(file_path, sorted_entries)
+        if original_ids != sorted_ids:
+            # We already have the lock, so we don't need to acquire it again
+            write_list_of_dicts_to_file(file_path, sorted_entries, use_lock=False)
 
 
 def load_dataset_entry(
@@ -461,7 +460,7 @@ def load_ground_truth_entry(test_category: str) -> list[dict]:
         return load_file(POSSIBLE_ANSWER_PATH / f"{VERSION_PREFIX}_{test_category}.json")
 
 
-def write_list_of_dicts_to_file(filename, data, subdir=None) -> None:
+def write_list_of_dicts_to_file(filename, data, subdir=None, use_lock: bool = True) -> None:
     """
     Write a list of dictionaries to a file.
     If `subdir` is provided, the file will be written to the subdirectory.
@@ -473,13 +472,22 @@ def write_list_of_dicts_to_file(filename, data, subdir=None) -> None:
         # Construct the full path to the file
         filename = os.path.join(subdir, os.path.basename(filename))
 
-    # Write the list of dictionaries to the file in JSON format
-    with open(filename, "w", encoding="utf-8") as f:
-        for i, entry in enumerate(data):
-            # Go through each key-value pair in the dictionary to make sure the values are JSON serializable
-            entry = make_json_serializable(entry)
-            json_str = json.dumps(entry, ensure_ascii=False) + "\n"
-            f.write(json_str)
+    abs_filename = os.path.abspath(filename)
+
+    def _write_entries(output_path: str):
+        """Internal helper that performs the actual write operation."""
+        with open(output_path, "w", encoding="utf-8") as f:
+            for i, entry in enumerate(data):
+                # Go through each key-value pair in the dictionary to make sure the values are JSON serializable
+                entry = make_json_serializable(entry)
+                json_str = json.dumps(entry, ensure_ascii=False) + "\n"
+                f.write(json_str)
+
+    if use_lock:
+        with _get_file_lock(abs_filename):
+            _write_entries(abs_filename)
+    else:
+        _write_entries(abs_filename)
 
 
 def make_json_serializable(value):
@@ -611,9 +619,9 @@ def is_empty_output(decoded_output):
 
 
 def _get_language_specific_hint(test_category):
-    if test_category == "java":
+    if is_java(test_category):
         return " Note that the provided function is in Java 8 SDK syntax."
-    elif test_category == "javascript":
+    elif is_js(test_category):
         return " Note that the provided function is in JavaScript syntax."
     else:
         return " Note that the provided function is in Python 3 syntax."
